@@ -15,7 +15,11 @@ def re_sub(re_pattern , text):
   return re.sub(re_pattern, text)
 
 
-
+def map_none(input=None):
+  if input is not None:
+    return input
+  else:
+    return ""
 
   
   
